//GoHclient.java: Copyright (C) 2001 Thomas Repantis <darkzero@otenet.gr>
//
//
//    This program is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program; if not, write to the Free Software
//    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
//

import java.net.*;
import java.io.*;


//GoHclient connects to the GoHserver, gives the connect or disconnect command,
//reads and displays the server's response.

public class GoHclient {

    public static void main(String[] args) throws IOException {
	

	//******************************************************************
	//_______________
	//Variables used.
	//---------------
	
	String host = "localhost";            //Host to connect to, if none supplied.
	Integer port = new Integer(14000);    //Port to connect to, if none supplied.

	InputStreamReader cmdISR = null;
	BufferedReader cmdBR = null;
	String command = null;

	Socket clientSocket = null;
	PrintWriter output = null;
	BufferedReader input = null;
      	String response = null;  	                           

	int i = 0;
	String arg;
	//******************************************************************


	//******************************************************************
	//___________________
	//Introduce yourself.
	//-------------------


	System.out.println();
	System.out.println("GoHclient");
	System.out.println("Copyright (C) 2001 Thomas Repantis <darkzero@otenet.gr>");   
	System.out.println("java GoHclient -h for help");
	System.out.println();


	//******************************************************************


	//******************************************************************
	//____________________________
	//Do the command line parsing.
	//----------------------------
	
	while (i < args.length && args[i].startsWith("-")) {

            arg = args[i++];
	    
	    if (arg.equals("-host")){
		if (i < args.length)
		    host = args[i++];
		else{
		    System.out.println();
		    System.err.println("-host requires a hostname");
		    System.err.println("java GoHclient -h for help");
		    System.out.println();
		    System.exit(1);
		}
	    }

	    else if (arg.equals("-port")){
		if (i < args.length){
		    try{
			port = new Integer(port.parseInt(args[i++]));    
		    } catch (NumberFormatException e) {
			System.err.println("Invalid port number.");
			System.exit(1);		
		    }
		}
		else{
		    System.out.println();
		    System.err.println("-port requires a portnumber");
		    System.err.println("java GoHclient -h for help");
		    System.out.println();
		    System.exit(1);
		}
	    }
	    
	    else if (arg.equals("-h")){
		//Give the poor user a little help...
	
		//***Hint1***
		System.out.println();
		System.out.println("Usage: java GoHclient [-h] [-host hostname] [-port portnumber]");
		
		//***Hint2***
		System.out.println();
		System.out.println("Gates of Heaven/Hell's purpose in life is to allow users from other machines to control connection to and disconnection from the Internet on an Internet gateway.");
		
		//***Hint3***
		System.out.println();
		System.out.println("GoHclient will connect to a GoHserver on the specified host (or on the localhost by default), on the specified port (or on port 14000 by default), give the connect or disconnect command, read and display the server's response.");
	    	
		//***Hint4***
		System.out.println();
		System.out.println("This program comes with ABSOLUTELY NO WARRANTY. This is free software, and you are welcome to redistribute it under certain conditions. TCPAgentClient is licensed under the GNU General Public License. See the file COPYING for details.");
	    	System.out.println();
		System.exit(1);
	    }
	    
	    else {
		System.err.println("Error in the command line arguments passed.");
		System.err.println("java GoHclient -h for help");
		System.exit(1);
	    }
	}

	if (i != args.length){
	    System.err.println("Error in the command line arguments passed.");
	    System.err.println("java GoHclient -h for help");
	    System.exit(1);
	}

	else{
	    System.out.println("Using host: " + host);	    
	    System.out.println("Using port: " + port);
	    System.out.println();
	    System.out.println("Please give the command \"connect\" or \"disconnect\".");
	    System.out.print("> ");
	    cmdISR = new InputStreamReader(System.in);
	    cmdBR = new BufferedReader(cmdISR);
	    command = null;
	    try{
		command = cmdBR.readLine();
	    } catch (IOException e) {
		System.err.println("Couldn't get I/O for the keyboard.");
		System.exit(1);
	    }
	    
	}
	
	
	//******************************************************************
	
	
	//******************************************************************
	//_____________________________________________________________
	//Connect to the server, send the command and get the response. 
	//-------------------------------------------------------------
	
	try {
	    
	    clientSocket = new Socket(host, port.intValue());
	    output = new PrintWriter(clientSocket.getOutputStream(), true);
	    input = new BufferedReader(new InputStreamReader(
							     clientSocket.getInputStream()));
	    
	    //_______________________________
	    //Send the command to the server.
	    //-------------------------------
	    output.println(command);
	    
	    
	    //_______________________________
	    //Get the response of the server.
	    //-------------------------------
	    
	    response = input.readLine();
	    
	    
	    //_________________________________
	    //Print the response of the server.
	    //---------------------------------
	    
	    System.out.println(response);
	    
	} catch (UnknownHostException e) {
	    System.err.println("Couldn't locate host.");
	    System.exit(1);
	    
	} catch (IOException e) {
	    System.err.println("Couldn't get I/O for the connection to the host.");
	    System.exit(1);
	}
	
	
	//Do the usual housekeeping.
	try {
	    
	    input.close();
		clientSocket.close();
		
	} catch (IOException e) {
	    System.err.println("Couldn't get I/O for the connection to the host.");
	    System.exit(1);
	}						
	//******************************************************************
    }
}


    
