//GoHthread.java: Copyright (C) 2001 Thomas Repantis <darkzero@otenet.gr>
//
//
//    This program is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program; if not, write to the Free Software
//    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
//

import java.net.*;
import java.io.*;
import java.util.*;

//GoHthread -once called- serves the server's client. That is, it
//gets either the connect or the disconnect command, runs the 
//necessary commands to connect to or disconnect from the Internet
//and sends a response (about the success of it all).

public class GoHthread extends Thread {


    //******************************************************************
    //_______________
    //Variables used.
    //---------------

    private Socket socket2client = null;
    private boolean logflag;
    
    PrintWriter output = null;
    BufferedReader input = null;

    String command = null;
    String response = null;

    int time = 0;
    int j = 0;

    //******************************************************************


    public GoHthread(Socket socket2client, boolean logflag) {
	
	super("GoHthread");
    
	//The thread is called and given as an argument the socket from 
	//which to receive the connect or disconnect command and to which
	//to write the response.
	this.socket2client = socket2client;
	this.logflag = logflag;
    }

    public void run() {

	try {

	    //____________________________
	    //Get command from the client.
	    //----------------------------
	    
	    input = new BufferedReader(new InputStreamReader(
				       socket2client.getInputStream()));
	    
	    command = input.readLine();
	    

	
	//______________________________________________________________________
	//Run the system commands to connect to or disconnect from the Internet.
	//----------------------------------------------------------------------
	
	if (command.equals("connect")){
	    
	    try{
		Process p = Runtime.getRuntime().exec("ppp -nat -auto OTEnet_ISDN");
	    } catch (IOException e) {
		System.err.println("Could not execute the system command.");
		System.exit(1);
	    }
	    response = "Connection to the Internet was successful. The gates are open!";
	}
	
	else if (command.equals("disconnect")){
	    
	    try{
		Process p = Runtime.getRuntime().exec("killall ppp");
	    } catch (IOException e) {
		System.err.println("Could not execute the system command.");
		System.exit(1);
	    }
	    response = "Disconnection from the Internet was successful. The gates are closed!";
	    
	}
		 
	else {
	    response = "Error in the command \""+command+"\" given. Please give the command \"connect\" or \"disconnect\".";
	} 

	   
	    //____________________________
	    //Send response to the client.
	    //----------------------------

	    output = new PrintWriter(socket2client.getOutputStream(), true);
	    
	    output.println(response);	   


		     



	    //___________________________________
	    //Log, if you 've been told to do so.
	    //-----------------------------------

	    if( logflag == true ){
                     		
		try{
		    //Successful connections will be logged. Connections
		    //that caused an exception will show up on the System.err.

		    //We preferred to give a standard name to the logfile,
		    //rather than a user defined one, in order to avoid
		    //problems, like overwriting existing irrelevant files
		    // and so on.

		    String logFileName = "GoHserver.log";
		    File logFile = new File(logFileName);

		    //We use the RandomAccessFile class, so that we can append
		    //data to an existing file.
		    RandomAccessFile log = new RandomAccessFile(logFile, "rw");
		    log.seek(logFile.length());
		  
		    Date logDate = new Date();
		    log.writeChars( logDate.toString() + " -> " + socket2client.toString() + " -> " + response);
		    //Write a new line to the logfile.
		    log.writeByte('\n');
		    log.close();
		} catch(IOException e) {

		    System.err.println("Could not write properly to the logfile.\n");
		    System.err.println(e.toString());
		    System.exit(1);

		}	    

	    }
		
	} catch (UnknownHostException e) {
	    System.err.println("Couldn't locate host.");
	    System.exit(1);
	} catch (IOException e) {
	    System.err.println("Couldn't get I/O for the connection to the host.");
	    System.exit(1);
	} catch (NullPointerException e) {
	    System.err.println("Somebody called the GoHserver without waiting for its response.");
	    System.exit(1);
	}
	
	
	//Do some housekeeping.
	try {
	    
	    input.close();
	    output.close();
		
	    socket2client.close();	
	    
	} catch (IOException e) {
	    System.err.println("Couldn't get I/O for the connection to the host.");
	    System.exit(1);
	}
	
	//******************************************************************						
    }
}



